import { ICrudService, IRobotCrudService, IUserCrudService, IRoleCrudService, ISettingCrudService, IAuditLogCrudService, ILogCrudService, IMachineCrudService, IReleaseCrudService, IProcessCrudService, IJobCrudService, IQueueDefinitionCrudService, IQueueCrudService, IAssetCrudService, IUtilService, ITenantCrudService, IHostLicenseCrudService, IEnvironmentCrudService, IQueueItemCrudService, IFolderCrudService, ILicenseCrudService } from './Interfaces';
export interface LicenseRuntimeDto {
    Key: string;
    MachineId: number;
    MachineName: string;
    Runtimes: number;
    RobotsCount: number;
    ExecutingCount: number;
    IsOnline: boolean;
    IsLicensed: boolean;
    Enabled: boolean;
}
export interface LicenseNamedUserDto {
    Key: string;
    UserName: string;
    LastLoginDate: Date;
    MachinesCount: number;
    IsLicensed: boolean;
    IsExternalLicensed: boolean;
    ActiveRobotId: number;
    MachineNames: string[];
    ActiveMachineNames: string[];
}
export interface LicenseDto {
    HostLicenseId: number;
    Id: number;
    ExpireDate: number;
    GracePeriodEndDate: number;
    GracePeriod: number;
    AttendedConcurrent: boolean;
    DevelopmentConcurrent: boolean;
    StudioXConcurrent: boolean;
    LicensedFeatures: string[];
    IsRegistered: boolean;
    IsExpired: boolean;
    CreationTime: Date;
    Code: string;
    Allowed: LicenseFields;
    Used: LicenseFields;
}
export interface LicenseFields {
    Unattended: number;
    Attended: number;
    NonProduction: number;
    Development: number;
    StudioX: number;
}
/**
 * Interfaceのデフォルト実装(全部でOverrideするのはメンドイので)
 */
export declare class BaseCrudService implements ICrudService {
    parent: IOrchestratorApi;
    constructor(parent: IOrchestratorApi);
    findAll(obj?: any, asArray?: boolean): Promise<Array<any>>;
    find(obj?: any): Promise<any>;
    create(obj: any): Promise<any>;
    update(obj: any): Promise<any>;
    delete(obj: any): Promise<any>;
    save2Excel(instances: any[], outputFullPath: string, templateFullPath?: string, sheetName?: string, applyStyles?: (instances: any[], workbook: any, sheetName: string) => void): Promise<string>;
    save2ExcelBlob(instances: any[], sheetName?: string, applyStyles?: (instances: any[], workbook: any, sheetName: string) => void): Promise<Blob>;
}
/**
 * Orchestrator API Wrapper
 * cf. https://docs.uipath.com/orchestrator/v2019/reference
 */
export interface IOrchestratorApi {
    authenticate: () => Promise<any>;
    license: ILicenseCrudService;
    robot: IRobotCrudService;
    user: IUserCrudService;
    role: IRoleCrudService;
    machine: IMachineCrudService;
    release: IReleaseCrudService;
    process: IProcessCrudService;
    library: IProcessCrudService;
    job: IJobCrudService;
    schedule: ICrudService;
    folder: IFolderCrudService;
    queueDefinition: IQueueDefinitionCrudService;
    queueItem: IQueueItemCrudService;
    queueOperation: IQueueCrudService;
    log: ILogCrudService;
    auditLog: IAuditLogCrudService;
    setting: ISettingCrudService;
    asset: IAssetCrudService;
    util: IUtilService;
    tenant: ITenantCrudService;
    hostLicense: IHostLicenseCrudService;
    environment: IEnvironmentCrudService;
    getArray: (apiPath: string, queries?: any) => Promise<Array<any>>;
    getData: (apiPath: string) => Promise<any>;
    postData: (apiPath: string, obj: any) => Promise<any>;
    putData: (apiPath: string, obj: any) => Promise<void>;
    deleteData: (apiPath: string) => Promise<any>;
    isEnterprise: boolean;
    isCommunity: boolean;
    isRobot: boolean;
    isToken: boolean;
    config: any;
    organizationUnitId: number;
    accessToken: string;
}
/**
 * OrchestratorのAPIのWrapperクラス
 * (Mainのクラスです)
 */
export declare class OrchestratorApi implements IOrchestratorApi {
    config: any;
    isEnterprise: boolean;
    isCommunity: boolean;
    isRobot: boolean;
    isToken: boolean;
    accessToken: string;
    get organizationUnitId(): number;
    set organizationUnitId(organizationUnitId: number);
    constructor(config: any);
    /**
     * Orchestrator API の認証システムに対して、認証を実施しアクセストークンを取得する。
     */
    authenticate(): Promise<any>;
    license: ILicenseCrudService;
    robot: IRobotCrudService;
    user: IUserCrudService;
    role: IRoleCrudService;
    machine: IMachineCrudService;
    release: IReleaseCrudService;
    process: IProcessCrudService;
    library: IProcessCrudService;
    job: IJobCrudService;
    schedule: ICrudService;
    folder: IFolderCrudService;
    tenant: ITenantCrudService;
    hostLicense: IHostLicenseCrudService;
    environment: IEnvironmentCrudService;
    queueDefinition: IQueueDefinitionCrudService;
    queueItem: IQueueItemCrudService;
    queueOperation: IQueueCrudService;
    log: ILogCrudService;
    auditLog: IAuditLogCrudService;
    setting: ISettingCrudService;
    asset: IAssetCrudService;
    util: IUtilService;
    getArray: (apiPath: string, queries?: any, isOdata?: boolean) => Promise<Array<any>>;
    getData: (apiPath: string) => Promise<any>;
    postData: (apiPath: string, obj: any) => Promise<any>;
    putData: (apiPath: string, obj: any) => Promise<any>;
    deleteData: (apiPath: string) => Promise<any>;
}
/**
 * 与えられたConfigの状態
 */
export declare const getConfigState: (config: any) => {
    isEnterprise: boolean;
    isCommunity: boolean;
    isRobot: boolean;
    isToken: boolean;
};
export default OrchestratorApi;
