"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AssetCrudService = void 0;
const __1 = require("..");
const utils_1 = require("../utils");
const excel_csv_read_write_1 = require("excel-csv-read-write");
const path_1 = __importDefault(require("path"));
class AssetCrudService extends __1.BaseCrudService {
    constructor(parent) {
        super(parent);
    }
    findAll(queries, asArray = true) {
        return utils_1.getArray(this.parent.config, this.parent.accessToken, '/odata/Assets', queries, asArray);
    }
    findAllEx(queries, asArray = true) {
        return utils_1.getArray(this.parent.config, this.parent.accessToken, '/odata/Assets', Object.assign({}, { $expand: 'RobotValues' }, queries), asArray);
    }
    find(id) {
        return utils_1.getData(this.parent.config, this.parent.accessToken, `/odata/Assets(${id})`);
    }
    // _findByUserName(userName: string): Promise<Array<any>> {
    //   return this.findAll({ $filter: `UserName eq '${userName}'` })
    // }
    // async findByUserName(userName: string): Promise<any> {
    //   const users: any[] = await this._findByUserName(userName)
    //   return users[0]
    // }
    update(asset) {
        return utils_1.putData(this.parent.config, this.parent.accessToken, `/odata/Assets(${asset.Id})`, asset);
    }
    create(asset) {
        return utils_1.postData(this.parent.config, this.parent.accessToken, '/odata/Assets', asset);
    }
    delete(id) {
        return utils_1.deleteData(this.parent.config, this.parent.accessToken, `/odata/Assets(${id})`);
    }
    async save2Excel(instances, outputFullPath, templateFullPath = path_1.default.join(__dirname, 'templates', 'templateAssets.xlsx'), sheetName = 'Sheet1', applyStyles) {
        const allRobotValues = instances.reduce((accumulator, current) => {
            // RobotValuesの列が来ないときもある。あるときだけ取得。
            if (current.RobotValues) {
                const robotValues = current.RobotValues.map(robotValue => Object.assign({}, robotValue, { AssetName: current.Name }));
                if (robotValues) {
                    accumulator.push(...robotValues);
                }
            }
            return accumulator; // コレ忘れる、、、
        }, []);
        // console.table(allRobotValues)
        // `perRobot_${outputFullPath}`,
        // `perRobot_${templateFullPath}`,
        const outputFullName = path_1.default.basename(outputFullPath);
        const templateFullName = path_1.default.basename(templateFullPath);
        const outputDir = path_1.default.dirname(outputFullPath);
        const templateDir = path_1.default.dirname(templateFullPath);
        // console.log(outputFullName)
        // console.log(templateFullName)
        // console.log(outputDir)
        // console.log(templateDir)
        const promises = Promise.all([
            super.save2Excel(instances, outputFullPath, templateFullPath, sheetName, applyStyles),
            super.save2Excel(allRobotValues, path_1.default.join(outputDir, `perRobot_${outputFullName}`), path_1.default.join(templateDir, `perRobot_${templateFullName}`), sheetName, applyStyles),
        ]);
        return new Promise((allResolve, reject) => {
            promises.then((results) => allResolve(results[0]));
        });
    }
    async upload(inputFullPath, sheetName = 'Sheet1', allProperty = false) {
        // const instances = await xlsx2json(inputFullPath, sheetName)
        // const ps = instances.map(instance => {
        //   if (allProperty) {
        //     return this.create(instance)
        //   } else {
        //     return this.create({
        //       Name: instance.Name,
        //       ValueType: instance.ValueType,
        //       Value: instance.Value,
        //       StringValue: instance.StringValue,
        //       BoolValue: instance.BoolValue,
        //       IntValue: instance.IntValue,
        //       Description: instance.Description,
        //       ValueScope: instance.ValueScope,
        //       HasDefaultValue: instance.HasDefaultValue,
        //     })
        //   }
        // })
        // return Promise.all(ps)
        return this.uploadPerRobot(inputFullPath, '', sheetName, '', allProperty);
    }
    async uploadPerRobot(inputFullPath, perRobotInputFullPath, sheetName = 'Sheet1', perRobotSheetName = 'Sheet1', allProperty = false) {
        const instances = await excel_csv_read_write_1.excel2json(inputFullPath, sheetName, (instance) => {
            return Object.assign({}, instance, {
                Value: String(instance.Value),
                StringValue: String(instance.StringValue),
            });
        });
        let perRobotInstances = [];
        if (perRobotInputFullPath !== '') {
            perRobotInstances = await excel_csv_read_write_1.excel2json(perRobotInputFullPath, perRobotSheetName, (instance) => {
                return Object.assign({}, instance, {
                    Value: String(instance.Value),
                    StringValue: String(instance.StringValue),
                });
            });
        }
        const ps = instances.map(async (instance) => {
            const perRobotValues = await this.findByAssetName(perRobotInstances, instance.Name);
            if (allProperty) {
                if (instance.ValueScope === 'PerRobot') {
                    Object.assign(instance, {
                        RobotValues: perRobotValues,
                    });
                }
                return this.create(instance);
            }
            else {
                const target = {
                    Name: instance.Name,
                    ValueType: instance.ValueType,
                    Value: instance.Value,
                    StringValue: instance.StringValue,
                    BoolValue: instance.BoolValue,
                    IntValue: instance.IntValue,
                    Description: instance.Description,
                    ValueScope: instance.ValueScope,
                    HasDefaultValue: instance.HasDefaultValue,
                };
                if (instance.ValueScope === 'PerRobot') {
                    Object.assign(target, {
                        RobotValues: perRobotValues,
                    });
                }
                return this.create(target);
            }
        });
        return Promise.all(ps);
    }
    async findByAssetName(perRobotInstances, assetName) {
        if (perRobotInstances.length > 0) {
            // PerRobotのシートから、instance と同じAsset名の行たちを取得して、
            // 新しいJSONをつくってますが、robotIdを取得するところが非同期なので、戻り値がPromiseになっちゃう。
            // 従って roboPromises は、Promise<any> の配列になってる
            const roboPromises = perRobotInstances
                .filter(perRobotInstance => perRobotInstance.AssetName === assetName)
                .map(value => this.addRoboId(value, this.parent));
            // 全部が終了するPromiseに変換して、await で待つようにして、JSONを取得した
            const perRobotValues = await Promise.all(roboPromises);
            return perRobotValues;
        }
    }
    async addRoboId(value, api) {
        const robot = await api.robot.findByRobotName(value.RobotName);
        return {
            RobotName: value.RobotName,
            RobotId: robot.Id,
            ValueType: value.ValueType,
            Value: value.Value,
            StringValue: value.StringValue,
            BoolValue: value.BoolValue,
            IntValue: value.IntValue,
        };
    }
}
exports.AssetCrudService = AssetCrudService;
//# sourceMappingURL=AssetCrudService.js.map