"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuditLogCrudService = void 0;
const __1 = require("..");
const utils_1 = require("../utils");
const path_1 = __importDefault(require("path"));
class AuditLogCrudService extends __1.BaseCrudService {
    constructor(parent) {
        super(parent);
    }
    findAll(queries, asArray = true) {
        return utils_1.getArray(this.parent.config, this.parent.accessToken, '/odata/AuditLogs', queries, asArray);
    }
    async findByFilter(filters, obj, asArray = true) {
        const filterArray = await utils_1.createAuditFilterStr(filters, this.parent);
        const filter = filterArray.join(' and ');
        if (filter === '') {
            return this.findAll(obj, asArray);
        }
        let condition = {};
        if (obj) {
            condition = obj;
            condition['$filter'] = filter;
        }
        else {
            condition = { $filter: filter };
        }
        return this.findAll(condition, asArray);
    }
    save2Excel(instances, outputFullPath, templateFullPath = path_1.default.join(__dirname, 'templates', 'templateAuditLog.xlsx'), sheetName = 'Sheet1', applyStyles) {
        const applyStyles_ = applyStyles
            ? applyStyles
            : (instances_, workbook, sheetName_) => {
                // Object.keys(instances_[0]).forEach(key => console.log(key))
                const sheet = workbook.sheet(sheetName_);
                const rowCount = instances_.length;
                // A列に、J列にあるUTCデータから JST変換を行う関数を入れている。
                // I列は、なぜかゼロがNULL値になっているので、0を入れる処理を入れている。
                for (let i = 0; i < rowCount; i++) {
                    const rowIndex = i + 2;
                    sheet
                        .cell(`A${rowIndex}`)
                        .formula(`=DATEVALUE(MIDB(D${rowIndex},1,10))+TIMEVALUE(MIDB(D${rowIndex},12,8))+TIME(9,0,0)`);
                }
                // JSTの時刻を入れている箇所に、日付フォーマットを適用
                sheet.range(`A2:A${rowCount + 1}`).style('numberFormat', 'yyyy/mm/dd hh:mm:ss;@');
            };
        return super.save2Excel(instances, outputFullPath, templateFullPath, sheetName, applyStyles_);
    }
}
exports.AuditLogCrudService = AuditLogCrudService;
//# sourceMappingURL=AuditLogCrudService.js.map