"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.JobCrudService = void 0;
const __1 = require("..");
const utils_1 = require("../utils");
const path_1 = __importDefault(require("path"));
class JobCrudService extends __1.BaseCrudService {
    constructor(parent) {
        super(parent);
    }
    findAll(queries, asArray = true) {
        return utils_1.getArray(this.parent.config, this.parent.accessToken, '/odata/Jobs', queries, asArray);
    }
    findAllEx(queries, asArray = true) {
        return utils_1.getArray(this.parent.config, this.parent.accessToken, '/odata/Jobs', Object.assign({}, { $expand: 'Robot,Release' }, queries), asArray);
    }
    find(id) {
        return utils_1.getData(this.parent.config, this.parent.accessToken, `/odata/Jobs(${id})`);
    }
    _startJobs(startInfo) {
        return utils_1.postData(this.parent.config, this.parent.accessToken, '/odata/Jobs/UiPath.Server.Configuration.OData.StartJobs', startInfo);
    }
    async startJobs(processKey, robotNames, jobsCount = 0) {
        const release = await this.parent.release.findByProcessKey(processKey);
        let promise;
        if (robotNames && robotNames.length > 0) {
            // logger.debug('Specific')
            // logger.debug(robotNames)
            // logger.debug(robotNames.length)
            const robotIdsPromise = robotNames.map(async (element) => {
                const instance = await this.parent.robot.findByRobotName(element);
                return instance.Id;
            });
            const robotIds = await Promise.all(robotIdsPromise);
            promise = this._startJobs({
                startInfo: {
                    ReleaseKey: release.Key,
                    RobotIds: robotIds,
                    JobsCount: 0,
                    Strategy: 'Specific',
                    InputArguments: '{}',
                },
            });
        }
        else {
            // logger.debug('JobsCount')
            // logger.debug(robotNames)
            // logger.debug(robotNames.length)
            promise = this._startJobs({
                startInfo: {
                    ReleaseKey: release.Key,
                    RobotIds: [],
                    JobsCount: jobsCount,
                    Strategy: 'JobsCount',
                    InputArguments: '{}',
                },
            });
        }
        return promise;
    }
    stopJob(jobId, force = false) {
        let strategy;
        if (force) {
            strategy = '2';
        }
        else {
            strategy = '1';
        }
        return utils_1.postData(this.parent.config, this.parent.accessToken, `/odata/Jobs(${jobId})/UiPath.Server.Configuration.OData.StopJob`, {
            strategy: strategy,
        });
    }
    save2Excel(instances, outputFullPath, templateFullPath = path_1.default.join(__dirname, 'templates', 'templateJobs.xlsx'), sheetName = 'Sheet1', applyStyles) {
        return super.save2Excel(instances, outputFullPath, templateFullPath, sheetName, applyStyles);
    }
}
exports.JobCrudService = JobCrudService;
//# sourceMappingURL=JobCrudService.js.map