"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LibraryCrudService = void 0;
const __1 = require("..");
const utils_1 = require("../utils");
const path_1 = __importDefault(require("path"));
class LibraryCrudService extends __1.BaseCrudService {
    constructor(parent) {
        super(parent);
    }
    /**
     * アクティブなバージョンに対しての検索。つまりプロセス一覧。
     * @param queries
     * @param asArray
     */
    findAll(queries, asArray = true) {
        return utils_1.getArray(this.parent.config, this.parent.accessToken, '/odata/Libraries', queries, asArray);
    }
    uploadPackage(fullPath, asArray = true) {
        return utils_1.uploadData(this.parent.config, this.parent.accessToken, '/odata/Libraries/UiPath.Server.Configuration.OData.UploadPackage()', fullPath, asArray);
    }
    /**
     * 画面上の名前を指定して、非アクティブなモノもふくめて検索する。
     * @param packageId
     * @param asArray
     */
    findPackage(packageId, asArray = true) {
        return utils_1.getArray(this.parent.config, this.parent.accessToken, `/odata/Libraries/UiPath.Server.Configuration.OData.GetVersions(packageId='${packageId}')`, {}, asArray);
    }
    deletePackage(packageId, version) {
        if (version) {
            return utils_1.deleteData(this.parent.config, this.parent.accessToken, `/odata/Libraries('${packageId}:${version}')`);
        }
        return utils_1.deleteData(this.parent.config, this.parent.accessToken, `/odata/Libraries('${packageId}')`);
    }
    /**
     *
     * @param key Sample:1.0.2 など、[packageId:version]
     */
    downloadPackage(id, version) {
        return utils_1.downloadData(this.parent.config, this.parent.accessToken, `/odata/Libraries/UiPath.Server.Configuration.OData.DownloadPackage(key='${id}:${version}')`, id, version);
    }
    save2Excel(instances, outputFullPath, templateFullPath = path_1.default.join(__dirname, 'templates', 'templateLibraries.xlsx'), sheetName = 'Sheet1', applyStyles) {
        return super.save2Excel(instances, outputFullPath, templateFullPath, sheetName, applyStyles);
    }
}
exports.LibraryCrudService = LibraryCrudService;
//# sourceMappingURL=LibraryCrudService.js.map