"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MachineCrudService = void 0;
const __1 = require("..");
const utils_1 = require("../utils");
const excel_csv_read_write_1 = require("excel-csv-read-write");
const path_1 = __importDefault(require("path"));
class MachineCrudService extends __1.BaseCrudService {
    constructor(parent) {
        super(parent);
    }
    findAll(queries, asArray = true) {
        return utils_1.getArray(this.parent.config, this.parent.accessToken, '/odata/Machines', queries, asArray);
    }
    find(id) {
        return utils_1.getData(this.parent.config, this.parent.accessToken, `/odata/Machines(${id})`);
    }
    _findByMachineName(machineName) {
        return this.findAll({ $filter: `Name eq '${machineName}'` });
    }
    async findByMachineName(machineName) {
        const machines = await this._findByMachineName(machineName);
        return machines[0];
    }
    create(machine) {
        return utils_1.postData(this.parent.config, this.parent.accessToken, '/odata/Machines', machine);
    }
    update(machine) {
        return utils_1.putData(this.parent.config, this.parent.accessToken, `/odata/Machines(${machine.Id})`, machine);
    }
    delete(id) {
        return utils_1.deleteData(this.parent.config, this.parent.accessToken, `/odata/Machines(${id})`);
    }
    async save2Excel(instances, outputFullPath, templateFullPath = path_1.default.join(__dirname, 'templates', 'templateMachines.xlsx'), sheetName = 'Sheet1', applyStyles) {
        const savedInstancesP = instances.map(async (instance) => {
            const machine = await this.parent.machine.find(instance.Id);
            return Object.assign({}, instance, { LicenseKey: machine.LicenseKey });
        });
        const savedInstances = await Promise.all(savedInstancesP);
        const converters = {
        // RobotVersions: (value: any) => value[0].Count,
        // RobotVersions: (value: any) => value[0].Version,
        };
        return excel_csv_read_write_1.json2excel(savedInstances, outputFullPath, templateFullPath, sheetName, converters, applyStyles);
        // return super.save2Excel(savedInstances, outputFullPath, templateFullPath, sheetName, applyStyles)
    }
    async save2ExcelBlob(instances, sheetName = 'Sheet1', applyStyles) {
        const savedInstancesP = instances.map(async (instance) => {
            const machine = await this.parent.machine.find(instance.Id);
            return Object.assign({}, instance, { LicenseKey: machine.LicenseKey });
        });
        const savedInstances = await Promise.all(savedInstancesP);
        const converters = {
        // RobotVersions: (value: any) => value[0].Count,
        // RobotVersions: (value: any) => value[0].Version,
        };
        return excel_csv_read_write_1.json2excelBlob(savedInstances, sheetName, converters, applyStyles);
        // return super.save2Excel(savedInstances, outputFullPath, templateFullPath, sheetName, applyStyles)
    }
    async upload(inputFullPath, sheetName = 'Sheet1', allProperty = false) {
        const machines = await excel_csv_read_write_1.excel2json(inputFullPath, sheetName);
        const promises = machines.map((machine) => {
            if (allProperty) {
                return this.create(machine);
            }
            else {
                return this.create({
                    Name: machine.Name,
                    Description: machine.Description,
                    Type: machine.Type,
                });
            }
        });
        return Promise.all(promises);
    }
}
exports.MachineCrudService = MachineCrudService;
//# sourceMappingURL=MachineCrudService.js.map