"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RobotCrudService = void 0;
const __1 = require("..");
const utils_1 = require("../utils");
const excel_csv_read_write_1 = require("excel-csv-read-write");
const path_1 = __importDefault(require("path"));
class RobotCrudService extends __1.BaseCrudService {
    constructor(parent) {
        super(parent);
    }
    findAll(queries, asArray = true) {
        return utils_1.getArray(this.parent.config, this.parent.accessToken, '/odata/Robots', queries, asArray);
    }
    find(id) {
        return utils_1.getData(this.parent.config, this.parent.accessToken, `/odata/Robots(${id})`);
    }
    _findByName(name) {
        return this.findAll({ $filter: `Name eq '${name}'` });
    }
    async findByRobotName(name) {
        const robos = await this._findByName(name);
        return robos[0];
    }
    create(robot) {
        return utils_1.postData(this.parent.config, this.parent.accessToken, '/odata/Robots', robot);
    }
    update(robot) {
        return utils_1.putData(this.parent.config, this.parent.accessToken, `/odata/Robots(${robot.Id})`, robot);
    }
    delete(id) {
        return utils_1.deleteData(this.parent.config, this.parent.accessToken, `/odata/Robots(${id})`);
    }
    save2Excel(instances, outputFullPath, templateFullPath = path_1.default.join(__dirname, 'templates', 'templateRobots.xlsx'), sheetName = 'Sheet1', applyStyles) {
        return super.save2Excel(instances, outputFullPath, templateFullPath, sheetName, applyStyles);
    }
    async upload(inputFullPath, sheetName = 'Sheet1', allProperty = false) {
        const robots = await excel_csv_read_write_1.excel2json(inputFullPath, sheetName);
        const promises = robots.map(async (robot) => {
            if (allProperty) {
                return this.create(robot);
            }
            else {
                // Machineがなかったら、つくるって処理も入れるべきだが一旦ナシで。
                // tmpを一度検索しているのは、Machine名検索だけだと、LicenseKey が空になるので、Idで再検索する。
                const tmp = await this.parent.machine.findByMachineName(robot.MachineName);
                const machine = await this.parent.machine.find(tmp.Id);
                // console.log(machine)
                return this.create({
                    MachineName: robot.MachineName,
                    LicenseKey: machine.LicenseKey,
                    Name: robot.Name,
                    Username: robot.Username,
                    Type: robot.Type,
                    RobotEnvironments: robot.RobotEnvironments,
                });
            }
        });
        return Promise.all(promises);
    }
}
exports.RobotCrudService = RobotCrudService;
//# sourceMappingURL=RobotCrudService.js.map