"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoleCrudService = void 0;
const __1 = require("..");
const utils_1 = require("../utils");
class RoleCrudService extends __1.BaseCrudService {
    constructor(parent) {
        super(parent);
    }
    findAll(queries, asArray = true) {
        return utils_1.getArray(this.parent.config, this.parent.accessToken, '/odata/Roles', queries, asArray);
    }
    find(id) {
        return utils_1.getData(this.parent.config, this.parent.accessToken, `/odata/Roles(${id})`);
    }
    findDetail(...keys) {
        return async (...methods) => {
            // まずは条件で検索
            const apiResults = await this.parent.getArray(`/odata/Permissions`);
            let filterResults = apiResults;
            if (keys.length > 0) {
                const tmpResults = keys // keyごとにFilterして
                    .map(key => apiResults.filter(apiResult => apiResult.Name.startsWith(key)))
                    .reduce((accumulator, current) => {
                    accumulator.push(...current); // 配列同士を結合
                    return accumulator;
                }, []);
                const resultSet = new Set(tmpResults); //ココで重複を除去
                // 最後は配列に戻して完成
                filterResults = Array.from(resultSet);
            }
            if (methods.length === 0) {
                console.log('引数なし');
                return filterResults;
            }
            return filterResults.filter(filterResult => {
                for (const method of methods) {
                    if (method === '') {
                        if (!filterResult.Name.includes('.')) {
                            return true;
                        }
                    }
                    else {
                        if (filterResult.Name.includes(method)) {
                            return true;
                        }
                    }
                }
                return false;
            });
        };
    }
    // _findByUserName(userName: string): Promise<Array<any>> {
    //   return this.findAll({ $filter: `UserName eq '${userName}'` })
    // }
    // async findByUserName(userName: string): Promise<any> {
    //   const users: any[] = await this._findByUserName(userName)
    //   return users[0]
    // }
    update(role) {
        return utils_1.putData(this.parent.config, this.parent.accessToken, `/odata/Roles(${role.Id})`, role);
    }
    create(role) {
        return utils_1.postData(this.parent.config, this.parent.accessToken, '/odata/Roles', role);
    }
    delete(id) {
        return utils_1.deleteData(this.parent.config, this.parent.accessToken, `/odata/Roles(${id})`);
    }
}
exports.RoleCrudService = RoleCrudService;
//# sourceMappingURL=RoleCrudService.js.map