"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SettingCrudService = void 0;
const __1 = require("..");
const utils_1 = require("../utils");
const excel_csv_read_write_1 = require("excel-csv-read-write");
const path_1 = __importDefault(require("path"));
class SettingCrudService extends __1.BaseCrudService {
    constructor(parent) {
        super(parent);
    }
    findAll(queries, asArray = true) {
        return utils_1.getArray(this.parent.config, this.parent.accessToken, '/odata/Settings', queries, asArray);
    }
    find(id) {
        return utils_1.getData(this.parent.config, this.parent.accessToken, `/odata/Settings('${id}')`);
    }
    // 可変長配列。使う側は、
    // findByKey('Abp.Net.Mail.Smtp', 'Abp.Net.Mail.Smtp.Host')とか、
    // これはあんま見ないけど
    // findByKey(...['Abp.Net.Mail.Smtp', 'Abp.Net.Mail.Smtp.Host']) とか。
    // keyは前方一致させている
    findByKey(queries) {
        return async (...keys) => {
            // まずは条件で検索
            const apiResults = await this.findAll(queries);
            return this._findByKeyFromArray(apiResults, ...keys);
        };
    }
    findByKeyFromArray(apiResults) {
        return (...keys) => {
            return this._findByKeyFromArray(apiResults, ...keys);
        };
    }
    _findByKeyFromArray(apiResults, ...keys) {
        // 案1
        const tmpResults = keys // keyごとにFilterして
            .map(key => apiResults.filter(apiResult => apiResult.Id.startsWith(key)))
            .reduce((accumulator, current) => {
            accumulator.push(...current); // 配列同士を結合
            return accumulator;
        }, []);
        const resultSet = new Set(tmpResults); //ココで重複を除去
        // 案2
        // const resultSet = new Set()
        // // わたされたkeyごとに、filterして、SetにAdd.
        // for (const key of keys) {
        //   apiResults
        //     .filter(apiResult => (apiResult.Id as string).startsWith(key))
        //     .map(filterResult => {
        //       resultSet.add(filterResult) // ココで重複が除去
        //     })
        // }
        // 最後は配列に戻して完成
        return Array.from(resultSet);
    }
    update(settingObjs) {
        return utils_1.postData(this.parent.config, this.parent.accessToken, '/odata/Settings/UiPath.Server.Configuration.OData.UpdateBulk', { settings: settingObjs });
    }
    readSettingsFromFile(fullPath, sheetName = 'Sheet1') {
        return excel_csv_read_write_1.excel2json(fullPath, sheetName, (instance) => {
            const value = instance.Value ? instance.Value : '';
            const scope = instance.Scope ? instance.Scope : null;
            return {
                Id: instance.Id,
                Name: instance.Name,
                Value: String(value),
                Scope: scope,
            };
        });
    }
    async getWebSettings() {
        const keyValues = await this.parent.getData('/odata/Settings/UiPath.Server.Configuration.OData.GetWebSettings');
        const keys = keyValues.Keys;
        const values = keyValues.Values;
        return keys.map((key, index) => {
            return {
                Id: key,
                Value: values[index],
            };
        });
    }
    save2Excel(settings, outputFullPath, templateFullPath = path_1.default.join(__dirname, 'templates', 'templateSettings.xlsx'), // テンプレファイルは、指定されたファイルか、このソースがあるディレクトリ上のtemplateSettings.xlsxを使う
    sheetName = 'Sheet1', applyStyles) {
        const applyStyles_ = applyStyles
            ? applyStyles
            : (settings_, workbook, sheetName_) => {
                const sheet = workbook.sheet(sheetName_);
                const rowCount = settings_.length;
                sheet.range(`C2:C${rowCount + 1}`).style('numberFormat', '@'); // 書式: 文字(コレをやらないと、見かけ上文字だが、F2で抜けると数字になっちゃう)
                // sheet.range(`E2:F${rowCount + 1}`).style('numberFormat', 'yyyy/mm/dd') // 書式: 日付
                // sheet.range(`H2:H${rowCount + 1}`).style('numberFormat', 'yyyy/mm/dd hh:mm') // 書式: 日付+時刻
            };
        return super.save2Excel(settings, outputFullPath, templateFullPath, sheetName, applyStyles_);
    }
}
exports.SettingCrudService = SettingCrudService;
//# sourceMappingURL=SettingCrudService.js.map