"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserCrudService = void 0;
const __1 = require("..");
const utils_1 = require("../utils");
const excel_csv_read_write_1 = require("excel-csv-read-write");
const path_1 = __importDefault(require("path"));
class UserCrudService extends __1.BaseCrudService {
    constructor(parent) {
        super(parent);
    }
    findAll(queries, asArray = true) {
        return utils_1.getArray(this.parent.config, this.parent.accessToken, '/odata/Users', queries, asArray);
    }
    find(id) {
        return utils_1.getData(this.parent.config, this.parent.accessToken, `/odata/Users(${id})`);
    }
    _findByUserName(userName) {
        return this.findAll({ $filter: `UserName eq '${userName}'` });
    }
    async findByUserName(userName) {
        const users = await this._findByUserName(userName);
        return users[0];
    }
    update(user) {
        return utils_1.putData(this.parent.config, this.parent.accessToken, `/odata/Users(${user.Id})`, user);
    }
    create(user) {
        return utils_1.postData(this.parent.config, this.parent.accessToken, '/odata/Users', user);
    }
    delete(id) {
        return utils_1.deleteData(this.parent.config, this.parent.accessToken, `/odata/Users(${id})`);
    }
    save2Excel(instances, outputFullPath, templateFullPath = path_1.default.join(__dirname, 'templates', 'templateUsers.xlsx'), // テンプレファイルは、指定されたファイルか、このソースがあるディレクトリ上のtemplateUsers.xlsxを使う
    sheetName = 'Sheet1', applyStyles) {
        return super.save2Excel(instances, outputFullPath, templateFullPath, sheetName, applyStyles);
    }
    async upload(inputFullPath, sheetName = 'Sheet1', allProperty = false) {
        const users = await excel_csv_read_write_1.excel2json(inputFullPath, sheetName);
        const promises = users.map(user => {
            if (allProperty) {
                return this.create(user);
            }
            else {
                return this.create({
                    Name: user.Name,
                    Surname: user.Surname,
                    UserName: user.UserName,
                    // FullName: 'User LastName',
                    EmailAddress: user.EmailAddress,
                    IsActive: user.IsActive,
                    Password: user.Password,
                    RolesList: JSON.parse(user.RolesList),
                });
            }
        });
        return Promise.all(promises);
    }
}
exports.UserCrudService = UserCrudService;
//# sourceMappingURL=UserCrudService.js.map