"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UtilService = void 0;
const path_1 = __importDefault(require("path"));
const excel_csv_read_write_1 = require("excel-csv-read-write");
class UtilService {
    constructor(api) {
        this.api = api;
    }
    async excelDownload(outputFullDir) {
        const promises = [];
        promises.push(...this._excelDownload(outputFullDir));
        const folders = await this.api.folder.findAll();
        for (const folder of folders) {
            promises.push(...this._excelDownloadPerFolder(outputFullDir, folder.Id));
        }
        return Promise.all(promises);
    }
    _excelDownloadPerFolder(outputFullDir, organizationUnitId) {
        const promises = [];
        this.api.organizationUnitId = organizationUnitId;
        promises.push(this.api.robot
            .findAll()
            .then((instances) => this.api.robot.save2Excel(instances, path_1.default.join(outputFullDir, `robots_${organizationUnitId}.xlsx`))));
        promises.push(this.api.environment
            .findAll()
            .then((instances) => this.api.environment.save2Excel(instances, path_1.default.join(outputFullDir, `environments_${organizationUnitId}.xlsx`))));
        promises.push(this.api.release
            .findAll()
            .then((instances) => this.api.release.save2Excel(instances, path_1.default.join(outputFullDir, `releases_${organizationUnitId}.xlsx`))));
        promises.push(this.api.job
            .findAllEx()
            .then((instances) => this.api.job.save2Excel(instances, path_1.default.join(outputFullDir, `jobs_${organizationUnitId}.xlsx`))));
        promises.push(this.api.asset
            .findAllEx()
            .then((instances) => this.api.asset.save2Excel(instances, path_1.default.join(outputFullDir, `assets_${organizationUnitId}.xlsx`))));
        promises.push(this.api.queueDefinition
            .findAll()
            .then((instances) => this.api.queueDefinition.save2Excel(instances, path_1.default.join(outputFullDir, `queueDefinitions_${organizationUnitId}.xlsx`))));
        return promises;
    }
    _excelDownload(outputFullDir) {
        const promises = [];
        promises.push(this.api.machine
            .findAll()
            .then((instances) => this.api.machine.save2Excel(instances, path_1.default.join(outputFullDir, 'machines.xlsx'))));
        promises.push(this.api.user
            .findAll()
            .then((instances) => this.api.user.save2Excel(instances, path_1.default.join(outputFullDir, 'users.xlsx'))));
        promises.push(this.api.process
            .findAll()
            .then((instances) => this.api.process.save2Excel(instances, path_1.default.join(outputFullDir, 'processes.xlsx'))));
        promises.push(this.api.library
            .findAll()
            .then((instances) => this.api.library.save2Excel(instances, path_1.default.join(outputFullDir, 'libraries.xlsx'))));
        promises.push(this.api.setting
            .findAll()
            .then((instances) => this.api.setting.save2Excel(instances, path_1.default.join(outputFullDir, 'settings.xlsx'))));
        promises.push(this.api.folder
            .findAll()
            .then((instances) => this.api.folder.save2Excel(instances, path_1.default.join(outputFullDir, 'folders.xlsx'))));
        return promises;
    }
    excelDownloadForHost(outputFullDir) {
        const promises = [];
        promises.push(this.api.hostLicense
            .findAll()
            .then((instances) => this.api.hostLicense.save2Excel(instances, path_1.default.join(outputFullDir, 'hostLicenses.xlsx'))));
        promises.push(this.api.tenant
            .findAll()
            .then((instances) => this.api.tenant.save2Excel(instances, path_1.default.join(outputFullDir, 'tenants.xlsx'))));
        return Promise.all(promises);
    }
    /**
     * 指定したパスにあるExcelファイルを読み込んで、console.table を使ってコンソールにダンプします。
     * @param fullPaths
     */
    async excel2Console(...fullPaths) {
        const promises = [];
        for (const fullPath of fullPaths) {
            promises.push(excel_csv_read_write_1.excel2json(fullPath).then((instances) => {
                console.log(`path : ${path_1.default.resolve(fullPath)}`);
                console.log(`count: ${instances.length}`);
                console.table(instances);
            }));
        }
        await Promise.all(promises);
        return new Promise((resolve, reject) => resolve());
    }
}
exports.UtilService = UtilService;
//# sourceMappingURL=UtilService.js.map